jactorch.functional.sampling
============================

.. automodule:: jactorch.functional.sampling

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      SampleBernoulli
      SampleMultinomial
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      choice
      sample_bernoulli
      sample_multinomial
   
   

   
   
   








.. rubric:: Class SampleBernoulli
.. autoclass:: SampleBernoulli
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SampleMultinomial
.. autoclass:: SampleMultinomial
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: choice

.. autofunction:: sample_bernoulli

.. autofunction:: sample_multinomial


